/* $Id: xio-rawip.h,v 1.13 2007/02/05 19:56:34 gerhard Exp $ */
/* Copyright Gerhard Rieger 2001-2007 */
/* Published under the GNU General Public License V.2, see file COPYING */

#ifndef __xio_rawip_h_included
#define __xio_rawip_h_included 1

extern const struct addrdesc addr_rawip_sendto;
extern const struct addrdesc addr_rawip_datagram;
extern const struct addrdesc addr_rawip_recvfrom;
extern const struct addrdesc addr_rawip_recv;
extern const struct addrdesc addr_rawip4_sendto;
extern const struct addrdesc addr_rawip4_datagram;
extern const struct addrdesc addr_rawip4_recvfrom;
extern const struct addrdesc addr_rawip4_recv;
extern const struct addrdesc addr_rawip6_sendto;
extern const struct addrdesc addr_rawip6_datagram;
extern const struct addrdesc addr_rawip6_recvfrom;
extern const struct addrdesc addr_rawip6_recv;

#endif /* !defined(__xio_rawip_h_included) */
